---
title: '[오픈공지] Port Letter(포트레터) 채널 오픈'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-03-18T10:02:37.923Z
---

### **Port Letter 채널이 OPEN 되었습니다!**



#### **포트원에게 해주고 싶으셨던 이야기가 있으신가요?**

포트원으로 자유롭게 편지를 보내실 수 있는 Port Letter 채널이 신규 개설되었습니다.
포트원을 사랑해 주시는 여러분의 소중한 의견을 기다리고 있으니 많은 성원 부탁드리며,
진심을 담아 보내주신 이야기들은 꼼꼼히 읽고 더 멋진 서비스로 보답 드리겠습니다!

포트원 일동 드림

<Callout title="Port Letter (의견보내기) 가기 ↗" />
